@@ -25,8 +25,20 @@ pub use k8s_openapi::apiextensions_apiserver::pkg::apis::apiextensions::v1 as ap
 pub use k8s_openapi::apimachinery::pkg::apis::meta::v1 as metav1;
 pub use k8s_openapi::Resource;
 
+pub use ext::ClusterRoleBindingExt;
+pub use ext::ClusterRoleExt;
+pub use ext::ConfigMapExt;
+pub use ext::DeploymentExt;
+pub use ext::NamespaceExt;
+pub use ext::ResourceExt;
+pub use ext::RoleBindingExt;
+pub use ext::RoleExt;
+pub use ext::SecretExt;
+pub use ext::ServiceAccountExt;
+
 pub use kubectl::Kubectl;
 
+mod ext;
 mod kubectl;
 
 pub fn typed_ref(
